@@ -5,13 +5,13 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl/smbc
+    home page: http://smbc.airm.net
   
     last update: 2004-05-26
 */
 
 #include "../config.h"
-#include "headers.h"
+#include "consts.h"
 
 typedef struct Tbookmark { 
   char username[RMAXGHLEN];
