@@ -5,79 +5,84 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl/smbc
+    home page: http://smbc.airm.net
   
-    last update: 2004-03-07
+    last update: 2004-08-06
 */
 #define _GNU_SOURCE
 
-#include "headers.h"
-#include "debug.h"
 #include "../config.h"
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else  /* not HAVE_STRING_H */
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif /* HAVE_STRINGS_H */
+#endif /* not HAVE_STRING_H */
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <stdio.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include "debug.h"
+#include "fnet.h"
 
 char *RdbgFile = NULL;
 
-void RinitDebug(char *Rstr)
+void 
+RinitDebugm(char *Rstr)
 {
   int Ri;
 
   Ri = strlen(Rstr)+1;
-  RdbgFile = malloc(Ri);
+  RdbgFile = Rmalloc(Ri);
   memcpy(RdbgFile, Rstr, Ri);
 }
 
-void RfreeDebug()
+void 
+RfreeDebugm()
 {
   free(RdbgFile);
   RdbgFile = NULL;
 }
 
-void RDBG(char *Rstr)
+void 
+RDBGm(char *Rstr)
 {
-#ifdef HAVE_DEBUG
   int Rdesc;
   char *Rms = "!!! debug message >> Rstr == NULL << debug message !!!\n";
 
   Rdesc = open(RdbgFile, O_CREAT | O_NONBLOCK | O_RDWR | O_APPEND, 0600); 
-  if (Rdesc > 0) {
+  if (Rdesc > 0) 
+  {
     if (Rstr) 
       write(Rdesc, Rstr, strlen(Rstr));
     else
       write(Rdesc, Rms, strlen(Rms));
     close(Rdesc);
   }
-#else
-  return;
-#endif /* HAVE_DEBUG */
 }
 
-int RDBGi(int Ri)
+int 
+RDBGim(int Ri)
 {
-#ifdef HAVE_DEBUG
   char *Rstr;
 
   asprintf(&Rstr, "%i", Ri);
-  RDBG(Rstr);
+  RDBGm(Rstr);
   free(Rstr);
   return(Ri);
-#else
-  return(Ri);
-#endif /* HAVE_DEBUG */
 }
 
-void RDBGc(char Rc)
+void 
+RDBGcm(char Rc)
 {
-#ifdef HAVE_DEBUG
   char *Rstr;
 
   asprintf(&Rstr, "%c", Rc);
-  RDBG(Rstr);
+  RDBGm(Rstr);
   free(Rstr);
-#else
-  return;
-#endif /* HAVE_DEBUG */
 }
