@@ -5,13 +5,12 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl/smbc
+    home page: http://smbc.airm.net
   
-    last update: 2004-05-03
+    last update: 2004-07-27
 */
 
 #include "../config.h"
-#include "headers.h"
 
 int RstrCmpIncludeFirst(const char *srcBig, const char *dstSmall);
 void RlistAllDownloadLists();
@@ -19,4 +18,6 @@ void RflushAllDownloadLists();
 void RdisplayVersion();
 void RShowAllItemsFromDUlist(int RnrDulist);
 int RsaveMessage(char *Rstr, char *RfileName);
+void RreturnHumanDelayTime(char **RtimeText, time_t Rtime);
+
 
