@@ -5,86 +5,122 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl
+    home page: http://smbc.airm.net
 
-  last update: 2004-05-25
+  last update: 2004-08-08
 */
 // -------------------------------------------------------------------
 #define _GNU_SOURCE
+
+#include "../config.h"
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else  /* not HAVE_STRING_H */
+#ifdef HAVE_STRINGS_H
+#include <strings.h>
+#endif /* HAVE_STRINGS_H */
+#endif /* not HAVE_STRING_H */
+
+#include <libsmbclient.h>
 #include <fcntl.h>
 #include <stdio.h>
-#include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <ctype.h>
+#include <signal.h>
 #include "fnet.h"
-#include "inet.h"
 #include "ierror.h"
 #include "debug.h"
-#include <libsmbclient.h>
 
 #define MAXLINE 512
 //static int smbc_compat_initialized = 0;
+
 #ifdef SAMBA3XX
 static SMBCCTX *statcont = NULL;
-#endif
+#endif /* SAMBA3XX */
 
-void reverse(char *str)
+void 
+reverse(char *str)
 {
   int c, i, j;
   
-  for (i=0, j=strlen(str)-1; i<j; i++, j--) {
+  for (i=0, j=strlen(str)-1; i<j; i++, j--) 
+  {
     c = str[i];
     str[i] = str[j];
     str[j] = c;
   }
 }
 
-void itoa(char *str, int n)
+void 
+itoa(char *str, int strLen, int n)
 {
-  int i, sign;
+  int sign;
+  char *RstrT = NULL;
+  char *RstrTT = NULL;
   
+  void itoaAddChar(char Rch)
+  {
+    asprintf(&RstrTT, "%s%c", RstrT?RstrT:"", Rch);
+    free(RstrT);
+    RstrT = RstrTT;
+  }
+
   if ((sign = n) < 0)
      n=-n;
-  i = 0;
-  do {
-    str[i++] = n % 10 + '0';
+  do 
+  {
+    itoaAddChar(n % 10 + '0');
   } while (( n /= 10 ) > 0);
   if (sign < 0)
-    str[i++] = '-';
-  str[i] = '\0';
-  reverse(str);  
+    itoaAddChar('-');
+  reverse(RstrT);
+  sign = strlen(RstrT);
+  if (sign+1-strLen > 0)
+    sign = strLen;
+  memcpy(str, RstrT, sign+1);
+  str[sign+1] = 0;
 }  
 
-int readline(register int fd, register char *ptr, register int maxlen)
+int 
+readline(register int fd, register char *ptr, register int maxlen)
 {
   int n, rc;
   char c;
   
-  for (n = 1; n < maxlen; n++) {
-    if ( (rc = read(fd, &c, 1)) == 1) {
+  for (n = 1; n < maxlen; n++) 
+  {
+    if ( (rc = read(fd, &c, 1)) == 1) 
+    {
       *ptr++ = c;
       if (c == '\n')
 	break;
-    } else if (rc == 0) {
-      if (n == 1)
-	return(0);
+    } 
+    else 
+      if (rc == 0) 
+      {
+        if (n == 1)
+          return(0);
+        else
+	  break;
+      } 
       else
-	break;
-    } else
-      return(-1);
+        return(-1);
   }
 
   *ptr = 0;
   return(n);
 }
 
-int writen(register int fd, register char *ptr, register int nbytes)
+int 
+writen(register int fd, register char *ptr, register int nbytes)
 {
   int nleft, nwritten;
 
   nleft = nbytes;
-  while (nleft > 0) {
+  while (nleft > 0) 
+  {
     nwritten = write(fd, ptr, nleft);
     if (nwritten <= 0)
       return(nwritten);
@@ -95,17 +131,20 @@ int writen(register int fd, register char *ptr, register int nbytes)
   return(nbytes - nleft);
 }
 
-void str_echo(int sockfd)
+void 
+str_echo(int sockfd)
 {
   int n;
   char line[MAXLINE];
 
-  for (;;) {
+  for (;;) 
+  {
     n = readline(sockfd, line, MAXLINE);
     if (n == 0)
       return;
-    else if (n < 0)
-      err_dump("str_echo: readline error");
+    else 
+      if (n < 0)
+        err_dump("str_echo: readline error");
 
     if (writen(sockfd, line, n) != n)
       err_dump("str_echo: writen error");
@@ -113,37 +152,39 @@ void str_echo(int sockfd)
 }
 
 
-int readlineii( int sockfd, char *buf, int size, int *linepos ) 
+int 
+readlineii(int sockfd, char *buf, int size, int *linepos) 
 {
   int n;
   char c;
     
-  while ( (n = read( sockfd, &c, 1)) == 1 )
-    {
-      buf[(*linepos)++] = c;
+  while ((n = read(sockfd, &c, 1)) == 1)
+  {
+    buf[(*linepos)++] = c;
 
-      if( c == '\n')
-	{
-	  buf[(*linepos)] = 0;
-	  *linepos = 0;
-	  return 1;
-	}
+    if ( c == '\n')
+    {
+      buf[(*linepos)] = 0;
+      *linepos = 0;
+      return 1;
     }
+  }
   if (!n)
     return -1;
   return(0);
 }    
 
-void refreshw(WINDOW *win, char *buf)
+void 
+refreshw(WINDOW *win, char *buf)
 {
   werase(win);
   mvwprintw(win, 1, 1, buf);
 }
 
-int readlineie(WINDOW *win, char *buf, int size, int *linepos ) 
+int 
+readlineie(WINDOW *win, char *buf, int size, int *linepos ) 
 {
   int klawisz;
-  //  char buft[MAXLINE], buftt[MAXLINE];
 
   nodelay(win, 1);
   klawisz = mvwgetch(win, 1, (*linepos)+1);
@@ -160,43 +201,37 @@ int readlineie(WINDOW *win, char *buf, int size, int *linepos )
        klawisz == 188 || klawisz == 172 ||   // ,
        klawisz == 230 || klawisz == 198 ||   // ,
        klawisz == 241 || klawisz == 209 ||   // ,
-      (klawisz == ' ' || klawisz == '/' || klawisz == '\\' || klawisz == '#')) {
+      (klawisz == ' ' || klawisz == '/' || klawisz == '\\' || klawisz == '#')) 
+  {
     buf[(*linepos)++] = (char)klawisz;
     buf[*linepos] = '\0';
     refreshw(win, buf);
     return (0);
   }
-  /*
-  itoa(buftt, klawisz);
-  strcpy(buft, buf);
-  strcat(buft, "###");
-  strcat(buft, buftt);
-  mvwprintw(win, 1, 1, buftt);
-  */
-  switch(klawisz) {
-  case 127: {
-    if (*linepos) {
-      buf[--(*linepos)] = '\0';
-      refreshw(win, buf);
-    }
-    break;
-  }
-  case 10: {
-    if (*linepos) {
-      buf[(*linepos)++] = '\n';
-      buf[*linepos] = '\0';
-      *linepos = 0;
-      werase(win);
-      return(1);
-    }
-    else
-      return(0);
-  }
+  switch(klawisz) 
+  {
+    case 127: if (*linepos) 
+              {
+                buf[--(*linepos)] = '\0';
+                refreshw(win, buf);
+              }
+              break;
+    case 10: if (*linepos) 
+             {
+               buf[(*linepos)++] = '\n';
+               buf[*linepos] = '\0';
+               *linepos = 0;
+               werase(win);
+               return(1);
+             }
+             else
+               return(0);
   }
   return(0);
 }    
 
-int readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair) 
+int 
+readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair) 
 {
   int klawisz, tmp;
   int startidx = 0;
@@ -206,25 +241,30 @@ int readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSiz
   curs_set(1);
   keypad(win, TRUE);
   refreshTxtInWin(win,wy,wx,buf, winSize, startidx, colorPair, A_NORMAL, 0);
-  while ((klawisz = mvwgetch(win, wy, wx+wxx-startidx)) != 0) {
-    //endwin(); printf(">%i|%i<\n", klawisz, KEY_LEFT); exit(0);
+  while ((klawisz = mvwgetch(win, wy, wx+wxx-startidx)) != 0) 
+  {
     esc = 1;
-    switch(klawisz) {
+    switch(klawisz) 
+    {
       case 263: 
-        if (strlen(buf) && wxx) {
-           if (strlen(buf) == wxx) {
+        if (strlen(buf) && wxx) 
+        {
+          if (strlen(buf) == wxx) 
              buf[strlen(buf)-1] = '\0';
-           }
-           else {
-             tmp = strlen(buf);
-             for (Ri = 0; Ri < tmp-wxx; Ri++)
-               buf[wxx+Ri] = buf[wxx+Ri+1]; 
-           }
-           if (startidx) { 
-             startidx--;
-             wxx--;
-           } else wxx--;
-           refreshTxtInWin(win,wy,wx,buf, winSize, startidx, colorPair, A_NORMAL, 0);
+          else 
+          {
+            tmp = strlen(buf);
+            for (Ri = 0; Ri < tmp-wxx; Ri++)
+              buf[wxx+Ri] = buf[wxx+Ri+1]; 
+          }
+          if (startidx) 
+          { 
+            startidx--;
+            wxx--;
+          } 
+          else 
+            wxx--;
+          refreshTxtInWin(win,wy,wx,buf, winSize, startidx, colorPair, A_NORMAL, 0);
         }
         esc = 0;
         break;
@@ -241,24 +281,28 @@ int readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSiz
         refreshTxtInWin(win,wy,wx,buf, winSize, startidx, colorPair, A_NORMAL, 0);
         break;
       case KEY_LEFT:
-        if ((startidx) && (startidx == wxx)) {
-           startidx--; wxx--;
+        if ((startidx) && (startidx == wxx)) 
+        {
+          startidx--; 
+          wxx--;
         }
-        else if (wxx) wxx--;
+        else 
+          if (wxx) 
+            wxx--;
         refreshTxtInWin(win,wy,wx,buf, winSize, startidx, colorPair, A_NORMAL, 0);
         esc = 0;
         break;
       case KEY_RIGHT:
-        //mvwprintw(win, 0, 0, "**>%i<**", ); wrefresh(RwinMain);
-        if (wxx < strlen(buf)) {
-          if ((startidx+winSize <= strlen(buf)) && (startidx+winSize == wxx+1)) {
-             startidx++; 
-             if( wxx+1 < strlen(buf)) wxx++;
+        if (wxx < strlen(buf)) 
+        {
+          if ((startidx+winSize <= strlen(buf)) && (startidx+winSize == wxx+1)) 
+          {
+            startidx++; 
+            if ( wxx+1 < strlen(buf)) 
+              wxx++;
           }
-          else {
+          else 
             wxx++;
-        //mvwprintw(win, 0, 0, "**>%i<**", wxx); wrefresh(win);
-          }
           refreshTxtInWin(win,wy,wx,buf, winSize, startidx, colorPair, A_NORMAL, 0);
           esc = 0;
         }
@@ -284,13 +328,16 @@ int readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSiz
          klawisz == 230 || klawisz == 198 ||   // ,
          klawisz == 241 || klawisz == 209 ||   // ,
          klawisz == '.' || klawisz == ',')) && 
-        (strlen(buf)+1 < sizebuf)) {
+        (strlen(buf)+1 < sizebuf)) 
+    {
         RDBG("fnet.c readlineWait: ok1\n");
-      if (wxx == strlen(buf)) {
+      if (wxx == strlen(buf)) 
+      {
         buf[wxx] = (char)klawisz;
         buf[wxx+1] = 0;
       }
-      else {
+      else 
+      {
         tmp = strlen(buf);
         for (Ri = 0; Ri < tmp-wxx+1; Ri++)
           buf[tmp+1-Ri] = buf[tmp-Ri];
@@ -304,7 +351,8 @@ int readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSiz
   return(0);
 }    
 
-int ssqr(int Rv, int Rpot)
+int 
+ssqr(int Rv, int Rpot)
 {
   int Ri;
   int Rr = 1;
@@ -313,7 +361,8 @@ int ssqr(int Rv, int Rpot)
   return(Rr);
 }
 
-int strhextoi(char *str)
+int 
+strhextoi(char *str)
 {
   int Ri;
   int Rm = strlen(str);
@@ -321,7 +370,8 @@ int strhextoi(char *str)
   char Rc;
   int Rci;
 
-  for (Ri = 0; Ri < Rm; Ri++) {
+  for (Ri = 0; Ri < Rm; Ri++) 
+  {
     Rc = str[strlen(str)-Ri-1];
     switch (Rc) {
       case 'A' :
@@ -337,14 +387,16 @@ int strhextoi(char *str)
       case 'F' : 
       case 'f' : Rci = 15; break;
       default : Rci = Rc-48;
-                if ((Rci < 0) | (Rci > 9)) return (-1);
+                if ((Rci < 0) | (Rci > 9)) 
+                  return (-1);
     }
     Rr+= Rci*ssqr(16,Ri);
   }
   return(Rr);
 }
 
-void RmvwprintwCenter(WINDOW *win, int i, char *str)
+void 
+RmvwprintwCenter(WINDOW *win, int i, char *str)
 {
   int y, x;
 
@@ -353,7 +405,8 @@ void RmvwprintwCenter(WINDOW *win, int i, char *str)
   wrefresh(win);
 }
 
-void refreshTxtInWin(WINDOW *win, int y, int x, char *buf, int winSize, int startidx, int colorPair, int attr, int xDelta)
+void 
+refreshTxtInWin(WINDOW *win, int y, int x, char *buf, int winSize, int startidx, int colorPair, int attr, int xDelta)
 {
   char *str;
 
@@ -362,20 +415,24 @@ void refreshTxtInWin(WINDOW *win, int y, int x, char *buf, int winSize, int star
     xDelta = winSize-1;
   RDBG("fnet refreshTxtInWin xDelta = "); RDBGi(xDelta); RDBG(", winSize = "); RDBGi(winSize); RDBG(",   startidx = "); RDBGi(startidx); RDBG("\n");
 
-  if (strlen(str+startidx) > winSize-1) str[startidx+winSize-1] = 0;
-  if (colorPair != -1) wattron(win, COLOR_PAIR(colorPair));
+  if (strlen(str+startidx) > winSize-1) 
+    str[startidx+winSize-1] = 0;
+  if (colorPair != -1) 
+    wattron(win, COLOR_PAIR(colorPair));
   mvwhline(win, y, x+xDelta, ' ', winSize-xDelta);
   wattron(win, attr);
   mvwprintw(win, y, x+xDelta, str+startidx);
   wattroff(win, attr);
-  if (colorPair != -1) wattroff(win, COLOR_PAIR(colorPair));
+  if (colorPair != -1) 
+    wattroff(win, COLOR_PAIR(colorPair));
   free(str);
 }
 
 //  0 <= xCursor <= strlen(buf)
 // startidx - start index for printing buf
 
-void refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, int startidx, int colorPair, int xCursor, int RpassMode)
+void 
+refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, int startidx, int colorPair, int xCursor, int RpassMode)
 {
   char *Rstr;
   int Rprinted = 0;
@@ -392,7 +449,8 @@ void refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, in
 
   Rbuf = strdup(buf);
 
-  if (RpassMode) {
+  if (RpassMode) 
+  {
     while (Rbuf[Ri])
       Rbuf[Ri++] = '*';
   }
@@ -417,17 +475,21 @@ void refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, in
   // char in curor position
   wattron(win, A_REVERSE);
   RDBG("fnet refreshTxtInWinCursor Rprinted = "); RDBGi(Rprinted); RDBG("\n");
-  if (Rprinted < winSize-1) {
-    if (Rprinted < Rstrl) {
+  if (Rprinted < winSize-1) 
+  {
+    if (Rprinted < Rstrl) 
+    {
       asprintf(&Rstr, "%c", Rbuf[xCursor]);
       RDBG("fnet refreshTxtInWinCursor 21\n");
     }
-    else {
+    else 
+    {
       asprintf(&Rstr, " ");
       RDBG("fnet refreshTxtInWinCursor 22\n");
     }
   }
-  else {
+  else 
+  {
     asprintf(&Rstr, " ");
     RDBG("fnet refreshTxtInWinCursor 23\n");
   }
@@ -440,7 +502,8 @@ void refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, in
   // some string after cursor
 
   if ((Rprinted < winSize-1) && 
-      (Rprinted+startidx < Rstrl)) {
+      (Rprinted+startidx < Rstrl)) 
+  {
     Rstr = strdup(Rbuf+startidx+Rprinted);
     if (winSize-Rprinted < strlen(Rstr))
        Rstr[winSize-Rprinted] = 0;
@@ -454,7 +517,8 @@ void refreshTxtInWinCursor(WINDOW *win, int y, int x, char *buf, int winSize, in
   free(Rbuf);
 }
 
-int readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int *startidx, int *wxx) 
+int 
+readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int *startidx, int *wxx) 
 {
   int Rfirst = 1;
   int Rt = 0;
@@ -465,54 +529,68 @@ int readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf,
 }
 
 // if first = 2 readlineOneCharNoDelay is in password mode
-int readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int Rnodelay, int *startidx, int *wxx, int *first)
+int 
+readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair, int *ctrlp, int Rnodelay, int *startidx, int *wxx, int *first)
 {
-  int klawisz;
+  int klawisz = 0;
   int esc, Ri;
   int Rbufl;
   int RpassMode = 0;
+  int Rit;
 
   if (!Rnodelay)
     curs_set(1);
   
   keypad(win, TRUE);
-  if (((*first) - 2) >= 0) {
+  if (((*first) - 2) >= 0) 
+  {
     RpassMode = 1;
     (*first) = (*first) -2;
   }
-  if (*first) {
+  if (*first) 
+  {
     refreshTxtInWinCursor(win,wy,wx,buf, winSize, *startidx, colorPair, *wxx, RpassMode);
     *first = 0;
   }
   if (RpassMode)
     (*first) = 2;
 
-  while ((klawisz = mvwgetch(win, wy, wx+(*wxx)-(*startidx))) != 0) {
-    //RDBG("fnet: readlineWaitForOneChar klawisz = "); RDBGi(klawisz); RDBG("\n");
+  while ((klawisz = mvwgetch(win, wy, wx+(*wxx)-(*startidx))) != 0) 
+  {
+    RDBG("fnet: readlineWaitForOneChar klawisz = "); RDBGi(klawisz); RDBG("\n");
     Rbufl = strlen(buf);
     esc = 1;
-    switch(klawisz) {
+    switch(klawisz) 
+    {
       case 263: // backspace 
-        if (Rbufl && (*wxx)) {
-           if (Rbufl == *wxx) {
+      case KEY_DC: // delete
+        if ((Rbufl && (*wxx) && (klawisz == 263)) || (Rbufl && (klawisz == KEY_DC))) 
+        {
+           if (Rbufl == *wxx) 
+           {
              buf[Rbufl-1] = '\0';
              Rbufl = strlen(buf);
            }
-           else {
-             for (Ri = 0; Ri < Rbufl-(*wxx); Ri++)
+           else 
+           {
+             Rit = Rbufl-(*wxx);
+             for (Ri = 0; Ri < Rit; Ri++)
                buf[(*wxx)+Ri] = buf[(*wxx)+Ri+1]; 
-               Rbufl = strlen(buf);
+             Rbufl = strlen(buf);
            }
-           if (*startidx) { 
-             (*startidx)--;
-             (*wxx)--;
-           } else (*wxx)--;
+           if (klawisz == 263) 
+           {
+             if (*startidx) 
+             { 
+               (*startidx)--;
+               (*wxx)--;
+             } else (*wxx)--;
+           };
            refreshTxtInWinCursor(win,wy,wx,buf, winSize, *startidx, colorPair, *wxx, RpassMode);
         }
         esc = 0;
         curs_set(0);
         return(0);
-        break;
       case KEY_HOME:
         *startidx = 0;
         (*wxx) = 0;
@@ -526,22 +604,28 @@ int readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf,
         refreshTxtInWinCursor(win,wy,wx,buf, winSize, *startidx, colorPair, *wxx, RpassMode);
         break;
       case KEY_LEFT:
-        if ((*startidx) && (*startidx == *wxx)) {
-           (*startidx)--; (*wxx)--;
+        if ((*startidx) && (*startidx == *wxx)) 
+        {
+          (*startidx)--; 
+          (*wxx)--;
         }
-        else if (*wxx) (*wxx)--;
+        else 
+          if (*wxx) 
+            (*wxx)--;
         refreshTxtInWinCursor(win,wy,wx,buf, winSize, *startidx, colorPair, *wxx, RpassMode);
         esc = 0;
         break;
       case KEY_RIGHT:
-        if ((*wxx) < Rbufl) {
-          if (((*startidx)+winSize <= Rbufl) && ((*startidx)+winSize == (*wxx)+1)) {
+        if ((*wxx) < Rbufl) 
+        {
+          if (((*startidx)+winSize <= Rbufl) && ((*startidx)+winSize == (*wxx)+1)) 
+          {
              (*startidx)++; 
-             if( (*wxx)+1 < Rbufl) (*wxx)++;
+             if ((*wxx)+1 < Rbufl) 
+               (*wxx)++;
           }
-          else {
+          else 
             (*wxx)++;
-          }
           refreshTxtInWinCursor(win,wy,wx,buf, winSize, *startidx, colorPair, *wxx, RpassMode);
           esc = 0;
         }
@@ -550,13 +634,15 @@ int readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf,
         curs_set(0);
         return(2);
       case 16:          // CTRL-p
-        if (*ctrlp) (*ctrlp) = 0;
-        else (*ctrlp) = 1;
+        if (*ctrlp) 
+          (*ctrlp) = 0;
+        else 
+          (*ctrlp) = 1;
         return(0);
       case 11:          // CTRL-k
         (*ctrlp) = 2;
         return(2);
-      case 9:          // TAB
+      case 9:           // TAB
         curs_set(0);
         return(1);
     }
@@ -577,11 +663,13 @@ int readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf,
          klawisz == 241 || klawisz == 209 ||   // ,
          klawisz == '.' || klawisz == ',')) && 
         (Rbufl+1 < sizebuf)) {
-      if ((*wxx) == Rbufl) {
+      if ((*wxx) == Rbufl) 
+      {
         buf[*wxx] = (char)klawisz;
         buf[(*wxx)+1] = 0;
       }
-      else {
+      else 
+      {
         for (Ri = 0; Ri < Rbufl-(*wxx)+1; Ri++)
           buf[Rbufl+1-Ri] = buf[Rbufl-Ri];
         buf[(*wxx)] = (char)klawisz;
@@ -603,7 +691,8 @@ int readlineOneCharNoDelay(WINDOW *win, int wy, int wx, char *buf, int sizebuf,
   return(0);
 }    
 
-void RstrToUpper(char *str)
+void 
+RstrToUpper(char *str)
 {
   int i;
   int k = strlen(str);
@@ -612,13 +701,15 @@ void RstrToUpper(char *str)
     str[i] = toupper(str[i]);
 }
 
-void RstrToUpperCopy(char *Dstr, char *Sstr)
+void 
+RstrToUpperCopy(char *Dstr, char *Sstr)
 {
   memcpy(Dstr, Sstr, strlen(Sstr)+1);
   RstrToUpper(Dstr);
 }
 
-void RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall)
+void 
+RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall)
 {
   char *Rstr;
   int Rlen, RlB, RlS, Rlo;
@@ -630,14 +721,17 @@ void RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall)
   RlS = strlen(RdirSmall);
   if ((RdirBig != NULL) &&
       (RdirSmall != NULL) &&
-      (RlB > RlS)) {
+      (RlB > RlS)) 
+  {
     Rlen = RlB - RlS + 1;
-    Rstr = malloc(Rlen);
+    Rstr = Rmalloc(Rlen);
     memcpy(Rstr, RdirBig+RlS, Rlen);
-    if (Rstr[0] == '/') Rs = 1;
-    if (Rstr[Rlen-2] == '/') Rstr[Rlen-2] = 0;
+    if (Rstr[0] == '/') 
+      Rs = 1;
+    if (Rstr[Rlen-2] == '/') 
+      Rstr[Rlen-2] = 0;
     Rlo = strlen(Rstr+Rs)+1;
-    *RfileName = malloc(Rlo);
+    *RfileName = Rmalloc(Rlo);
     memcpy(*RfileName, Rstr+Rs, Rlo);
     RDBG("fnet: RgetFileFromTwoDirs return : "); RDBG(*RfileName); RDBG("\n");
   }
@@ -645,3 +739,18 @@ void RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall)
     *RfileName = NULL;
 }
 
+void *
+Rmalloc(size_t Isize)
+{
+  void *Rret;
+
+  Rret = malloc(Isize);
+  if (Rret == NULL) 
+  {
+    RDBG("fnet: Rmalloc malloc failed\n");
+    kill(getpid(), SIGSEGV);
+    return(NULL);
+  }
+  return(Rret);
+}
+
