@@ -5,9 +5,9 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl
+    home page: http://smbc.airm.net
 
-  last update: 2004-05-25
+  last update: 2004-08-08
 */
 // -------------------------------------------------------------------
 #include <curses.h>
@@ -19,7 +19,7 @@ int readlineii( int sockfd, char *buf, int size, int *linepos );
 int readlineie(WINDOW *win, char *buf, int size, int *linepos );
 void refreshw(WINDOW *win, char *buf);
 void reverse(char *str);
-void itoa(char *str, int n);
+void itoa(char *str, int strLen, int n);
 void refreshTxtInWin(WINDOW *win, int y, int x, char *buf, int winSize, int startidx, int colorPair, int attr, int xDelta);
 int readlineWait(WINDOW *win, int wy, int wx, char *buf, int sizebuf, int winSize, int colorPair);
 int ssqr(int Rv, int Rpot);
@@ -30,4 +30,4 @@ int readlineWaitForOneChar(WINDOW *win, int wy, int wx, char *buf, int sizebuf,
 void RstrToUpper(char *str);
 void RstrToUpperCopy(char *Dstr, char *Sstr);
 void RgetFileFromTwoDirs(char **RfileName, char *RdirBig, char *RdirSmall);
-
+void *Rmalloc(size_t size);
