@@ -5,20 +5,19 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl
+    home page: http://smbc.airm.net
 */
 // -------------------------------------------------------------------
-#include "ierror.h"
 #include <stdio.h>
 
-void err_dump(char *st)
+void 
+err_dump(char *st)
 {
   printf("%s\n", st);
 }
 
-#include "ierror.h"
-
-void err_sys(char *st)
+void 
+err_sys(char *st)
 {
   printf("%s\n", st);
 }
