@@ -5,7 +5,7 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl
+    home page: http://smbc.airm.net
 */
 // -------------------------------------------------------------------
 void err_dump(char *st);
