@@ -5,15 +5,22 @@
        author: Rafal Michniewicz 
         email: <rafim@data.pl>
        jabber: rafim@jabber.org
-    home page: http://www.air.rzeszow.pl
+    home page: http://smbc.airm.net
 
   last update: 2004-05-03
 */
 // -------------------------------------------------------------------
 
+#include "consts.h"
+
 #define RMAXDIRLEN 1000
+#define TdownloadsizeDisplayRLen 6
+#define TdownloadsizeDisplayDownR 6
+#define TdownloadpercentLen 4 
 
 typedef struct Tdownload {
+  char username[RMAXGHLEN];
+  char password[RMAXGHLEN];
   char groupnameR[RMAXGHLEN];
   char pathRbase[RMAXDIRLEN];
   char pathR[RMAXDIRLEN];
@@ -21,12 +28,14 @@ typedef struct Tdownload {
   char fullfilename[2000];
   char filename[RMAXGHLEN];
   unsigned int sizeR;
-  char sizeDisplayR[10];
-  char sizeDisplayDownR[10];
-  char percent[5];
+  char sizeDisplayR[TdownloadsizeDisplayRLen];
+  char sizeDisplayDownR[TdownloadsizeDisplayDownR];
+  char percent[TdownloadpercentLen];
   char active;
   char upload; 
   struct Tdownload *RdownloadList;
   struct Tdownload *RdownloadListP;
+  time_t delayRetry;
+  time_t nextRetry;
 } TTdownload;
 
