@@ -11,7 +11,8 @@
 */
 
 #include "../config.h"
-#include "headers.h"
+
+#define RstrCmp(src, dst) (!strcmp(src, dst))
 
 #ifdef HAVE_SMBCCTX
 SMBCCTX * Rsmbc_set_context(SMBCCTX * new_context);
