@@ -13,6 +13,8 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <libsmbclient.h>
+#include <unistd.h>
 #include "winpopup.h"
 #include "debug.h"
 
